@@ -347,11 +347,12 @@ class OAuthenticator(Authenticator):
     async def authenticate(self, handler, data=None):
         raise NotImplementedError()
 
+    _deprecated_oauth_aliases = {}
 
-    def _deprecated_trait(self, change):
+    def _deprecated_oauth_trait(self, change):
         """observer for deprecated traits"""
         old_attr = change.name
-        new_attr, version = self._deprecated_aliases.get(old_attr)
+        new_attr, version = self._deprecated_oauth_aliases.get(old_attr)
         new_value = getattr(self, new_attr)
         if new_value != change.new:
             # only warn if different
@@ -366,3 +367,11 @@ class OAuthenticator(Authenticator):
                 )
             )
             setattr(self, new_attr, change.new)
+
+    def __init__(self, **kwargs):
+        # observe deprecated config names in oauthenticator
+        if self._deprecated_oauth_aliases:
+            self.observe(
+                self._deprecated_oauth_trait, names=list(self._deprecated_oauth_aliases)
+            )
+        super().__init__(**kwargs)
